from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import NotificationCenter


class TestNCWidgetController(TestCase):
    @min_os_level("10.10")
    def testClasses10_10(self):
        self.assertIsInstance(NotificationCenter.NCWidgetController, objc.objc_class)

        self.assertArgIsBOOL(
            NotificationCenter.NCWidgetController.setHasContent_forWidgetWithBundleIdentifier_,
            0,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import NotificationCenter


class TestNCWidgetListViewDelegateHelper(NotificationCenter.NSObject):
    def widgetList_viewControllerForRow_(self, wl, r):
        return 1

    def widgetList_shouldReorderRow_(self, wl, r):
        return 1

    def widgetList_didReorderRow_toRow_(self, wl, r, r2):
        pass

    def widgetList_shouldRemoveRow_(self, wl, r):
        return 1

    def widgetList_didRemoveRow_(self, wl, r):
        return 1


class TestNCWidgetListViewController(TestCase):
    @min_os_level("10.10")
    def testClasses10_10(self):
        self.assertIsInstance(
            NotificationCenter.NCWidgetListViewController, objc.objc_class
        )

        self.assertResultIsBOOL(
            NotificationCenter.NCWidgetListViewController.hasDividerLines
        )
        self.assertArgIsBOOL(
            NotificationCenter.NCWidgetListViewController.setHasDividerLines_, 0
        )

        self.assertResultIsBOOL(NotificationCenter.NCWidgetListViewController.editing)
        self.assertArgIsBOOL(
            NotificationCenter.NCWidgetListViewController.setEditing_, 0
        )

        self.assertResultIsBOOL(
            NotificationCenter.NCWidgetListViewController.showsAddButtonWhenEditing
        )
        self.assertArgIsBOOL(
            NotificationCenter.NCWidgetListViewController.setShowsAddButtonWhenEditing_,
            0,
        )

        self.assertArgIsBOOL(
            NotificationCenter.NCWidgetListViewController.viewControllerAtRow_makeIfNecessary_,
            1,
        )

    @min_os_level("10.11")
    def testProtocols(self):
        objc.protocolNamed("NCWidgetListViewDelegate")

        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_viewControllerForRow_,
            1,
            objc._C_NSUInteger,
        )

        self.assertResultIsBOOL(
            TestNCWidgetListViewDelegateHelper.widgetList_shouldReorderRow_
        )
        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_shouldReorderRow_,
            1,
            objc._C_NSUInteger,
        )

        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_didReorderRow_toRow_,
            1,
            objc._C_NSUInteger,
        )
        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_didReorderRow_toRow_,
            2,
            objc._C_NSUInteger,
        )

        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_shouldRemoveRow_,
            1,
            objc._C_NSUInteger,
        )
        self.assertArgHasType(
            TestNCWidgetListViewDelegateHelper.widgetList_didRemoveRow_,
            1,
            objc._C_NSUInteger,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import NotificationCenter


class TestNCWidgetSearchViewDelegateHelper(NotificationCenter.NSObject):
    def widgetSearch_searchForTerm_maxResults_(self, a, b, c):
        pass


class TestNCWidgetSearchViewControlle(TestCase):
    @min_os_level("10.10")
    def testClasses10_10(self):
        objc.protocolNamed("NCWidgetSearchViewDelegate")

        self.assertArgHasType(
            TestNCWidgetSearchViewDelegateHelper.widgetSearch_searchForTerm_maxResults_,
            2,
            objc._C_NSUInteger,
        )



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import NotificationCenter


class TestNCWidgetProvidingHelper(NotificationCenter.NSObject):
    def widgetPerformUpdateWithCompletionHandler_(self, handler):
        pass

    def widgetMarginInsetsForProposedMarginInsets_(self, insets):
        return insets

    def widgetAllowsEditing(self):
        return True


class TestNCWidgetProviding(TestCase):
    @min_os_level("10.10")
    def testConstants10_10(self):
        self.assertEqual(NotificationCenter.NCUpdateResultNewData, 0)
        self.assertEqual(NotificationCenter.NCUpdateResultNoData, 1)
        self.assertEqual(NotificationCenter.NCUpdateResultFailed, 2)

    @min_os_level("10.10")
    def testClasses10_10(self):
        objc.protocolNamed("NCWidgetProviding")

        self.assertArgIsBlock(
            TestNCWidgetProvidingHelper.widgetPerformUpdateWithCompletionHandler_,
            0,
            b"v" + objc._C_NSUInteger,
        )
        self.assertResultHasType(
            TestNCWidgetProvidingHelper.widgetMarginInsetsForProposedMarginInsets_,
            NotificationCenter.NSEdgeInsets.__typestr__,
        )
        self.assertArgHasType(
            TestNCWidgetProvidingHelper.widgetMarginInsetsForProposedMarginInsets_,
            0,
            NotificationCenter.NSEdgeInsets.__typestr__,
        )
        self.assertResultIsBOOL(TestNCWidgetProvidingHelper.widgetAllowsEditing)



"""
Python mapping for the NotificationCenter framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Cocoa
import objc
from NotificationCenter import _metadata, _NotificationCenter

sys.modules["NotificationCenter"] = mod = objc.ObjCLazyModule(
    "NotificationCenter",
    "com.apple.notificationcenter",
    objc.pathForFramework("/System/Library/Frameworks/NotificationCenter.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_NotificationCenter, Cocoa),
)


del sys.modules["NotificationCenter._metadata"]
del sys.modules["NotificationCenter._NotificationCenter"]



"""
Wrappers for the "NotificationCenter" framework on macOS.

These wrappers don't include documentation, please check Apple's documentation
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks
"""

import os

from pyobjc_setup import Extension, setup

VERSION = "8.3"

setup(
    name="pyobjc-framework-NotificationCenter",
    description="Wrappers for the framework NotificationCenter on macOS",
    min_os_level="10.10",
    packages=["NotificationCenter"],
    ext_modules=[
        Extension(
            "NotificationCenter._NotificationCenter",
            ["Modules/_NotificationCenter.m"],
            extra_link_args=["-framework", "NotificationCenter"],
            py_limited_api=True,
            depends=[
                os.path.join("Modules", fn)
                for fn in os.listdir("Modules")
                if fn.startswith("_NotificationCenter")
            ],
        )
    ],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
    options={"bdist_wheel": {"py_limited_api": "cp36"}},
)



# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:43:31 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$NCUpdateResultFailed@2$NCUpdateResultNewData@0$NCUpdateResultNoData@1$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"NCWidgetController", b"defaultWidgetController", {"deprecated": 1010})
    r(
        b"NCWidgetController",
        b"setHasContent:forWidgetWithBundleIdentifier:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"NCWidgetListViewController", b"editing", {"retval": {"type": "Z"}})
    r(b"NCWidgetListViewController", b"hasDividerLines", {"retval": {"type": "Z"}})
    r(b"NCWidgetListViewController", b"setEditing:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"NCWidgetListViewController",
        b"setHasDividerLines:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"NCWidgetListViewController",
        b"setShowsAddButtonWhenEditing:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"NCWidgetListViewController",
        b"showsAddButtonWhenEditing",
        {"retval": {"type": "Z"}},
    )
    r(
        b"NCWidgetListViewController",
        b"viewControllerAtRow:makeIfNecessary:",
        {"arguments": {3: {"type": "Z"}}},
    )
    r(b"NSObject", b"widgetAllowsEditing", {"required": False, "retval": {"type": "Z"}})
    r(
        b"NSObject",
        b"widgetDidBeginEditing",
        {"required": False, "retval": {"type": b"v"}},
    )
    r(
        b"NSObject",
        b"widgetDidEndEditing",
        {"required": False, "retval": {"type": b"v"}},
    )
    r(
        b"NSObject",
        b"widgetList:didRemoveRow:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Q"}},
        },
    )
    r(
        b"NSObject",
        b"widgetList:didReorderRow:toRow:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Q"}, 4: {"type": "Q"}},
        },
    )
    r(
        b"NSObject",
        b"widgetList:shouldRemoveRow:",
        {
            "required": False,
            "retval": {"type": "Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Q"}},
        },
    )
    r(
        b"NSObject",
        b"widgetList:shouldReorderRow:",
        {
            "required": False,
            "retval": {"type": "Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Q"}},
        },
    )
    r(
        b"NSObject",
        b"widgetList:viewControllerForRow:",
        {
            "required": True,
            "retval": {"type": b"@"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Q"}},
        },
    )
    r(
        b"NSObject",
        b"widgetListPerformAddAction:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"widgetMarginInsetsForProposedMarginInsets:",
        {
            "required": False,
            "retval": {"type": "{NSEdgeInsets=dddd}"},
            "arguments": {2: {"type": "{NSEdgeInsets=dddd}"}},
        },
    )
    r(
        b"NSObject",
        b"widgetPerformUpdateWithCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": sel32or64(b"I", b"Q")},
                        },
                    },
                    "type": "@?",
                }
            },
        },
    )
    r(
        b"NSObject",
        b"widgetSearch:resultSelected:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"widgetSearch:searchForTerm:maxResults:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": sel32or64(b"I", b"Q")},
            },
        },
    )
    r(
        b"NSObject",
        b"widgetSearchTermCleared:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
